@@ -19,21 +19,15 @@
  *****************************************************************************/
 
 #include "filemetadataconfigwidget.h"
+#include "filemetadataprovider.h"
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kfilemetainfo.h>
-#include <kfilemetainfoitem.h>
-#include <klocale.h>
+#include <KConfig>
+#include <KConfigGroup>
 
-#include <KDebug>
-
-#include "filemetadataprovider_p.h"
-#include <kfilemetadata/propertyinfo.h>
-
-#include <QEvent>
-#include <QListWidget>
-#include <QVBoxLayout>
+#include <QtCore/QEvent>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QVBoxLayout>
+#include <QtCore/QDebug>
 
 using namespace Baloo;
 
@@ -80,8 +74,7 @@ FileMetaDataConfigWidget::Private::Private(FileMetaDataConfigWidget* parent) :
 
     m_provider = new FileMetaDataProvider(q);
     m_provider->setReadOnly(true);
-    connect(m_provider, SIGNAL(loadingFinished()),
-            q, SLOT(slotLoadingFinished()));
+    connect(m_provider, SIGNAL(loadingFinished()), q, SLOT(slotLoadingFinished()));
 }
 
 FileMetaDataConfigWidget::Private::~Private()
@@ -139,7 +132,7 @@ void FileMetaDataConfigWidget::Private::slotLoadingFinished()
     // Always show these 3
     data.remove("rating");
     data.remove("tags");
-    data.remove("comment");
+    data.remove("userComment");
 
     QVariantMap::const_iterator it = data.constBegin();
     while (it != data.constEnd()) {
@@ -149,7 +142,7 @@ void FileMetaDataConfigWidget::Private::slotLoadingFinished()
 
     addItem("rating");
     addItem("tags");
-    addItem("comment");
+    addItem("userComment");
 }
 
 FileMetaDataConfigWidget::FileMetaDataConfigWidget(QWidget* parent) :
@@ -193,7 +186,7 @@ void FileMetaDataConfigWidget::save()
 bool FileMetaDataConfigWidget::event(QEvent* event)
 {
     if (event->type() == QEvent::Polish) {
-        kDebug() << "GOT POLISH EVENT!!!";
+        qDebug() << "GOT POLISH EVENT!!!";
         // loadMetaData() must be invoked asynchronously, as the list
         // must finish it's initialization first
         QMetaObject::invokeMethod(this, "loadMetaData", Qt::QueuedConnection);
@@ -206,4 +199,4 @@ QSize FileMetaDataConfigWidget::sizeHint() const
     return d->m_metaDataList->sizeHint();
 }
 
-#include "filemetadataconfigwidget.moc"
+#include "moc_filemetadataconfigwidget.cpp"
