@@ -22,8 +22,8 @@
 #define INDEXEDDATARETRIEVER_H
 
 #include <KJob>
-#include <KProcess>
-#include <QVariant>
+#include <QtCore/QProcess>
+#include <QtCore/QVariant>
 
 namespace Baloo {
 
@@ -34,11 +34,11 @@ public:
     IndexedDataRetriever(const QString& fileUrl, QObject* parent = 0);
     virtual ~IndexedDataRetriever();
 
-    virtual void start();
+    virtual void start() Q_DECL_OVERRIDE;
 
     QVariantMap data() const;
 
-private slots:
+private Q_SLOTS:
     void slotIndexedFile(int error);
 
 private:
