@@ -18,12 +18,12 @@
 #ifndef KEDIT_TAGS_DIALOG_H
 #define KEDIT_TAGS_DIALOG_H
 
-#include <kdialog.h>
+#include <QtWidgets/QDialog>
 
-class KLineEdit;
+class QLineEdit;
 class KJob;
-class QListWidget;
-class QListWidgetItem;
+class QTreeWidget;
+class QTreeWidgetItem;
 class QPushButton;
 class QTimer;
 
@@ -35,39 +35,37 @@ class QTimer;
  *
  * @see KMetaDataConfigurationDialog
  */
-class KEditTagsDialog : public KDialog
+class KEditTagsDialog : public QDialog
 {
     Q_OBJECT
 
 public:
     KEditTagsDialog(const QStringList& tags,
-                    QWidget* parent = 0,
-                    Qt::WFlags flags = 0);
+                    QWidget* parent = 0);
 
     virtual ~KEditTagsDialog();
 
     QStringList tags() const;
 
-protected slots:
-    virtual void slotButtonClicked(int button);
-
-private slots:
+private Q_SLOTS:
     void slotTextEdited(const QString& text);
+    void slotAcceptedButtonClicked();
 
-    void slotTagsLoaded(KJob* job);
+
+    void slotItemActivated(const QTreeWidgetItem* item, int column);
 
 private:
-    void loadTags();
-    void removeNewTagItem();
+    void loadTagWidget();
+    void modifyTagWidget(const QString& tag);
 
 private:
+    QHash<QString, QTreeWidgetItem*> m_allTagTreeItems;
     QStringList m_tags;
     QStringList m_allTags;
+    QString m_newTag;
 
-    QListWidget* m_tagsList;
-    QListWidgetItem* m_newTagItem;
-    QListWidgetItem* m_autoCheckedItem;
-    KLineEdit* m_newTagEdit;
+    QTreeWidget* m_tagTree;
+    QLineEdit* m_newTagEdit;
 };
 
 #endif
