@@ -25,17 +25,12 @@
 #include "kedittagsdialog_p.h"
 #include "tagcheckbox.h"
 
-#include <kinputdialog.h>
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kglobalsettings.h>
-#include <kdebug.h>
+#include <KLocalizedString>
 #include <KJob>
 
-#include <QtGui/QPushButton>
-#include <QtGui/QBoxLayout>
-#include <QtGui/QLabel>
-#include <QtCore/QSet>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QBoxLayout>
+#include <QtWidgets/QLabel>
 
 using namespace Baloo;
 
@@ -48,7 +43,8 @@ void TagWidgetPrivate::init( TagWidget* parent )
 
     QGridLayout* mainLayout = new QGridLayout( q );
     mainLayout->setMargin(0);
-    m_flowLayout = new KBlockLayout( 0, KDialog::spacingHint()*3 );
+    //TODO spacingHint should be declared. Old code  m_flowLayout = new KBlockLayout( 0, KDialog::spacingHint()*3 );
+    m_flowLayout = new KBlockLayout( 0 );
     mainLayout->addLayout( m_flowLayout, 0, 0, 1, 2 );
     mainLayout->setColumnStretch( 0, 1 );
 }
@@ -86,7 +82,7 @@ void TagWidgetPrivate::buildTagHash(const QStringList& tags)
         f.setUnderline(true);
         m_showAllLinkLabel->setFont(f);
         m_showAllLinkLabel->setText( QLatin1String("<a href=\"add_tags\">") +
-                                        ( m_checkBoxHash.isEmpty() ? i18nc("@label", "Add Tags...") : i18nc("@label", "Change...") ) +
+                                        ( m_checkBoxHash.isEmpty() ? i18nc("@label", "Add...") : i18nc("@label", "Change...") ) +
                                         QLatin1String("</a>") );
         q->connect( m_showAllLinkLabel, SIGNAL(linkActivated(QString)), SLOT(slotShowAll()) );
     }
@@ -192,5 +188,3 @@ void TagWidget::slotKEditTagDialogFinished(int result)
     d->m_editTagsDialog = 0;
 }
 
-
-#include "tagwidget.moc"
